@@ -33,7 +33,7 @@ import gtk
 # Solfege modules
 ###################
 from solfege import gu
-from solfege import learningtree
+from solfege import frontpage
 from solfege import lessonfile
 from solfege import mpd
 import solfege
@@ -115,7 +115,7 @@ class ExercisesMenuAddIn(object):
                 for section in column:
                     item = gtk.MenuItem(section.m_name)
                     for link in section:
-                        if isinstance(link, learningtree.Page):
+                        if isinstance(link, frontpage.Page):
                             item = gtk.MenuItem(link.m_name)
                             menu.append(item)
                             item.set_submenu(create_menu(link))
@@ -149,7 +149,7 @@ class ExercisesMenuAddIn(object):
                                     "1cadef8c-859e-4482-a6c4-31bd715b4787",
                                     ):
                                 continue
-                            item = gtk.MenuItem(lessonfile.infocache.get(link, 'title'))
+                            item = gtk.MenuItem(_(lessonfile.infocache.get(link, 'title')))
                             item.connect('activate', self.on_select_exercise, link)
                             menu.append(item)
             return menu
